v0.2.1
======

2020/08/28

* Support for GeoPy 2.0+
* Support for Pandas 1.0+

v0.2.0
======

2018/11/02

* Python 3 compatibility (preserving compatibility with Python 2)
  * Updated demo for cross compatibility
  * Added Python 3 to travis
* Support latest version of Pandana v0.4.1 (preserving compatibility with prior versions)
* Removed integration test using Great Britain dataset as data no longer available for download
* Updated readme and docs

v0.1.0
======

2017/8/02

* Initial release
